summaryrefslogtreecommitdiff
path: root/ci.scm
diff options
context:
space:
mode:
Diffstat (limited to 'ci.scm')
-rw-r--r--ci.scm8
1 files changed, 4 insertions, 4 deletions
diff --git a/ci.scm b/ci.scm
index 46a32fe..3416e8e 100644
--- a/ci.scm
+++ b/ci.scm
@@ -1,4 +1,4 @@
;; webid-oidc, implementation of the Solid specification
;; Copyright (C) 2020, 2021 Vivien Kraus
;; This program is free software: you can redistribute it and/or modify
@@ -14,7 +14,7 @@
;; You should have received a copy of the GNU Affero General Public License
;; along with this program. If not, see <https://www.gnu.org/licenses/>.
-(use-modules (vkraus packages webid-oidc))
+(use-modules (vkraus packages disfluid))
(use-modules (gnu packages bash))
(use-modules (gnu packages base))
(use-modules (gnu packages tex))
@@ -71,14 +71,14 @@
(interned-file tmp-dirname "ci-checkout" #:recursive? #t))))
(delete-file-recursively tmp-dirname)
interned))))
- (let ((dist-without-maintainer (dist-package webid-oidc-snapshot checked-out-index))
+ (let ((dist-without-maintainer (dist-package disfluid-snapshot checked-out-index))
(version
(car
(string-split
(call-with-input-file (string-append checked-out-index "/.tarball-version")
get-string-all)
#\newline))))
- (let ((tar-name (string-append "webid-oidc-" version ".tar.gz")))
+ (let ((tar-name (string-append "disfluid-" version ".tar.gz")))
(computed-file
tar-name
#~(let ((source
@@ -1,4 +1,4 @@
-;; webid-oidc, implementation of the Solid specification
+;; disfluid, implementation of the Solid specification
;; Copyright (C) 2020, 2021 Vivien Kraus
;; This program is free software: you can redistribute it and/or modify